@@ -39,7 +39,9 @@ class DoorLock(Device):
         # Convert to lowercase just like SmartRent website does
         value = str(value).lower()
 
-        await self._async_send_command(attribute_name="locked", value=value)
+        await self._client._async_send_command(
+            self, attribute_name="locked", value=value
+        )
 
     def _fetch_state_helper(self, data: dict):
         """
